@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: DAV
 version: 1.2
-id: DAV-1.2-ae024cb51706f5e54023437899011d4c
-key: DAV_0tAiBOmPopcE31pppNUdhw
+id: DAV-1.2-805245b73d271fedbc5e5bbca96428ae
+key: DAV_IGkhIYmNqE872xUcAXXWUb
 license: GPL-3
 copyright: Copyright (C) 2012-2015  Clint Adams
 maintainer: clint@debian.org
@@ -26,25 +26,25 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/DAV-1.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/DAV-1.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/DAV-1.2
-hs-libraries: HSDAV-1.2-0tAiBOmPopcE31pppNUdhw
+hs-libraries: HSDAV-1.2-IGkhIYmNqE872xUcAXXWUb
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    case-insensitive-1.2.0.6-c6baeb35be7a5ef7e8151f5e00d87f59
+    case-insensitive-1.2.0.6-f940e4aded76d28f250fda2e1500b30b
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
+    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
     exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
-    http-client-0.4.27.1-bb782af803807428bd58a3e7494afa2a
-    http-client-tls-0.2.3-dfa8d8f591f2399ab0bdf7c21e1d9977
-    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
-    lens-4.13.2.1-51cb0aae339c8977636563c0e1cbdfa1
+    http-client-0.4.28-3a5d04f7eb5922409c889a37b339ae0f
+    http-client-tls-0.2.4-ad0e9a866e1feb2eac114d565c18f6c6
+    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
+    lens-4.14-628d47acbc5f1414216cede3732a90db
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
     transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
     transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
     utf8-string-1.0.1.1-55be01444fdc59e978af349d80596373
-    xml-conduit-1.3.4.1-75d80fe52680bbdca276c9f509509d3e
-    xml-hamlet-0.4.0.11-0c1bb389bc2a3ce0045aa2368d4cab75
+    xml-conduit-1.3.5-b0d7925ea0f1a62fe18b3cdd25dd3416
+    xml-hamlet-0.4.0.11-bcb43e99f97583f59903928997a32e4a
 haddock-interfaces: /usr/share/doc/haskell-dav/html/DAV.haddock
 haddock-html: /usr/share/doc/haskell-dav/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
